@@ -175,6 +175,10 @@ Can accept a path. The following are valid viewname arguments
 ```
 This will create a view file in the appropriate folder, create a mirrored scss file in the site directory, and
 import the style into the main styles.scss file.
+
+###generatedocs
+
+Adds a `/docs` folder and copies some basic documentation into it
 """
 def generate_docs(dir):
     if not os.path.exists(dir + os.sep + 'docs'):
